# AuditActionTypeDto


## Enum

* `INSERT` (value: `'insert'`)

* `UPDATE` (value: `'update'`)

* `DELETE` (value: `'delete'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


